/*
 * Pest Pedal.c
 *
 * Created: 11/6/2017 7:09:30 PM
 * Author : ppotty
 */ 

#define F_CPU	1000000

#define MT_WR	0
#define MT_CS	1
#define MT_RS0	2
#define MT_RD	3

#include <avr/io.h>
#include <util/delay.h>



unsigned char mt_read() {
	unsigned char mt_data;
	DDRA = 0x0F;
	PORTA = (1 << MT_RD) | (1 << MT_WR);	// drop CS with WR and RD up and RS0 down
	PORTA &= ~(1 << MT_RD);					// drop RD
	mt_data = PINB & 0x0F;					// get the nibble from D3~D0
	PORTA |= (1 << MT_RD);					// raise RD
	PORTA |= (1 << MT_CS);					// raise CS
	return mt_data;
}

void mt_write(unsigned char data) {
	DDRA = 0xFF;
	PORTA = (1 << MT_RD) | (1 << MT_WR);	// drop CS with WR and RD up and RS0 down
	PORTA &= ~(1 << MT_WR);					// drop WR
	PORTA |= data << 4;						// write the nibble to D3~D0
	PORTA |= (1 << MT_WR);					// raise WR
	PORTA |= (1 << MT_CS);					// raise CS
}

void dial_digit(unsigned char digit) {
	mt_write(digit);
	_delay_ms(200);
}

void mt_init() {
	_delay_ms(100);	// wait for MT8888 to stabilize

	PORTA = 0;

	// read status register
	DDRA = 0x0F;
	PORTA = (1 << MT_RD) | (1 << MT_WR) | (1 << MT_RS0);// drop CS with WR RD and RS0 up
	PORTA &= ~(1 << MT_RD);								// drop RD
	PORTA |= (1 << MT_RD);								// raise RD
	PORTA |= (1 << MT_CS);								// raise CS
	PORTA &= ~(1 <<MT_RS0);								// drop RS0
	
	// write control register
	DDRA = 0xFF;
	PORTA = 0;											// put 0 on from D3~D0
	PORTA = (1 << MT_RD) | (1 << MT_WR) | (1 << MT_RS0);// drop CS with WR RD and RS0 up
	PORTA &= ~(1 << MT_WR);								// drop WR
	PORTA |= (1 << MT_WR);								// raise WR
	PORTA |= (1 << MT_CS);								// raise CS
	PORTA &= ~(1 <<MT_RS0);								// drop RS0
	
	// write control register
	PORTA = (1 << MT_RD) | (1 << MT_WR) | (1 << MT_RS0);// drop CS with WR RD and RS0 up
	PORTA &= ~(1 << MT_WR);								// drop WR
	PORTA |= (1 << MT_WR);								// raise WR
	PORTA |= (1 << MT_CS);								// raise CS
	PORTA &= ~(1 <<MT_RS0);								// drop RS0
	
	// write control register
	PORTA = (1 << MT_RD) | (1 << MT_WR) | (1 << MT_RS0);// drop CS with WR RD and RS0 up
	PORTA &= ~(1 << MT_WR);								// drop WR
	PORTA |= 0x80;										// put 1000b on from D3~D0
	PORTA |= (1 << MT_WR);								// raise WR
	PORTA |= (1 << MT_CS);								// raise CS
	PORTA &= ~(1 <<MT_RS0);								// drop RS0
	
	// write control register
	PORTA &= ~(0xF0);											// put 0 on from D3~D0
	PORTA = (1 << MT_RD) | (1 << MT_WR) | (1 << MT_RS0);// drop CS with WR RD and RS0 up
	PORTA &= ~(1 << MT_WR);								// drop WR
	PORTA |= (1 << MT_WR);								// raise WR
	PORTA |= (1 << MT_CS);								// raise CS
	PORTA &= ~(1 <<MT_RS0);								// drop RS0
	
	// read status register
	DDRA = 0x0F;
	PORTA = (1 << MT_RD) | (1 << MT_WR) | (1 << MT_RS0);// drop CS with WR RD and RS0 up
	PORTA &= ~(1 << MT_RD);								// drop RD
	PORTA |= (1 << MT_RD);								// raise RD
	PORTA |= (1 << MT_CS);								// raise CS
	PORTA &= ~(1 <<MT_RS0);								// drop RS0
	

	// write control register with wanted config
	DDRA = 0xFF;
	PORTA = (1 << MT_RD) | (1 << MT_WR) | (1 << MT_RS0);// drop CS with WR RD and RS0 up
	PORTA &= ~(1 << MT_WR);								// drop WR
	PORTA |= 0xD0;										// put 1101b on from D3~D0 for tone out, IRQ and Register B
	PORTA |= (1 << MT_WR);								// raise WR
	PORTA |= (1 << MT_CS);								// raise CS
	PORTA &= ~(1 <<MT_RS0);								// drop RS0
	
	PORTA = (1 << MT_RD) | (1 << MT_WR) | (1 << MT_RS0);// drop CS with WR RD and RS0 up
	PORTA &= ~(1 << MT_WR);								// drop WR
	PORTA &= ~0xF0;										// put 0 on from D3~D0 for burst mode
	PORTA |= (1 << MT_WR);								// raise WR
	PORTA |= (1 << MT_CS);								// raise CS
	PORTA &= ~(1 <<MT_RS0);								// drop RS0
}


int main(void) {
	unsigned char delay_loop;
	DDRA = 0xFF;			// MT data port to all output
	DDRB = (1 << PORTB1);	// relay output
	
	PORTB = (1 << PORTB0);	// pull up button
	
	mt_init();
	
	while (1) {
		while (PINB & (1 << PORTB0)) {		//wait for button press
		}
		PORTB |= (1 << PORTB1);
		_delay_ms(500);
		
		// dial extension number 1007
		dial_digit(1);
		dial_digit(10);
		dial_digit(10);
		dial_digit(7);
		
		for (delay_loop = 0; delay_loop < 20; delay_loop++) {
			_delay_ms(500);
		}
		
		PORTB &= ~(1 << PORTB1);
	}
}

